Ext4Reader

Struct Ext4Reader 

pub struct Ext4Reader<T: Seek + Read> {
    pub fs: BufReader<T>,
    pub blocksize: u16,
    pub offset_start: u64,
    /* private fields */
}
Create a reader that can parse the ext4 filesystem

Fields

fs: BufReader<T>blocksize: u16

Default is probably 4096

offset_start: u64

Will be 0. Unless you are reading a disk image file like QCOW or VMDK

Implementations

Source

impl<T: Seek + Read> Ext4Reader<T>

pub fn new( fs: BufReader<T>, blocksize: u16, offset_start: u64, ) -> Result<Ext4Reader<T>, Ext4Error>

Initialize an ext4 filesystem reader. This reader will automatically set the correct blocksize if you do not know it